==> zeppelin-0.8.2.tgz: zeppelin-0.8.2/zeppelin-interpreter/src/main/java/org/apache/zeppelin/tabledata/TableDataProxy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.zeppelin.tabledata;

import org.apache.zeppelin.resource.Resource;

import java.util.Iterator;

/**
 * Proxy TableData for ResourcePool
 */
public class TableDataProxy implements TableData {
  private final Resource resource;

  public TableDataProxy(Resource tableDataRemoteResource) {
    this.resource = tableDataRemoteResource;
  }

  @Override
  public ColumnDef[] columns() {
    return (ColumnDef[]) resource.invokeMethod(
        "columns", null, null);
  }

  @Override
  public Iterator<Row> rows() {
    String resourceName = resource.getResourceId().getName() + ".rows";
    Resource rows = resource.invokeMethod("rows", null, null, resourceName);

    ProxyRowIterator it = new ProxyRowIterator(rows);
    return it;
  }
}

==> zeppelin-0.10.1.tgz: zeppelin-0.10.1/zeppelin-interpreter/src/main/java/org/apache/zeppelin/tabledata/TableDataProxy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.zeppelin.tabledata;

import org.apache.zeppelin.resource.Resource;

import java.util.Iterator;

/**
 * Proxy TableData for ResourcePool
 */
public class TableDataProxy implements TableData {
  private final Resource resource;

  public TableDataProxy(Resource tableDataRemoteResource) {
    this.resource = tableDataRemoteResource;
  }

  @Override
  public ColumnDef[] columns() {
    return (ColumnDef[]) resource.invokeMethod(
        "columns");
  }

  @Override
  public Iterator<Row> rows() {
    String resourceName = resource.getResourceId().getName() + ".rows";
    Resource rows = resource.invokeMethod("rows", resourceName);

    ProxyRowIterator it = new ProxyRowIterator(rows);
    return it;
  }
}
